@@ -485,8 +485,9 @@ class DataConstantsTransformerForm(forms.ModelForm):
     type = forms.CharField(required=False,
                            widget=forms.TextInput(attrs={'class': 'form-control'}))
 
-    index = forms.CharField(required=False,
-                            widget=forms.HiddenInput(attrs={'class': 'form-control'}))
+    index = forms.IntegerField(required=False,
+                               widget=forms.HiddenInput(attrs={'class': 'form-control'}),
+                               initial=0)
     value = forms.CharField(required=False,
                             widget=forms.TextInput(attrs={'class': 'form-control'}))
     data_transformer = forms.ModelChoiceField(required=False, queryset=DataTransformerTypes.objects.all(), widget=forms.HiddenInput(attrs={'class': 'form-control'}))
@@ -499,8 +500,9 @@ class DataConstantsTransformerForm(forms.ModelForm):
 class HardwareTransformerForm(forms.ModelForm):
     id = forms.CharField(required=False,
                          widget=forms.HiddenInput(attrs={'class': 'form-control'}))
-    index = forms.CharField(required=False,
-                            widget=forms.HiddenInput(attrs={'class': 'form-control'}))
+    index = forms.IntegerField(required=False,
+                               widget=forms.HiddenInput(attrs={'class': 'form-control'}),
+                               initial=0)
     data_transformer = forms.ModelChoiceField(required=False, queryset=DataTransformerTypes.objects.all(), widget=forms.HiddenInput(attrs={'class': 'form-control'}))
 
     class Meta:
@@ -511,8 +513,9 @@ class HardwareTransformerForm(forms.ModelForm):
 class HardwareStatsTransformerForm(forms.ModelForm):
     id = forms.CharField(required=False,
                          widget=forms.HiddenInput(attrs={'class': 'form-control'}))
-    index = forms.CharField(required=False,
-                            widget=forms.HiddenInput(attrs={'class': 'form-control'}))
+    index = forms.IntegerField(required=False,
+                            widget=forms.HiddenInput(attrs={'class': 'form-control'}),
+                               initial=0)
     data_transformer = forms.ModelChoiceField(required=False, queryset=DataTransformerTypes.objects.all(), widget=forms.HiddenInput(attrs={'class': 'form-control'}))
 
 
